@@ -1,8 +1,7 @@
 package Net::IPAddress::Util::Collection;
 
-use 5.010000;
-use strict;
-use warnings;
+use 5.012000;
+use utf8;
 
 require Net::IPAddress::Util;
 require Net::IPAddress::Util::Collection::Tie;
@@ -22,7 +21,7 @@ sub sorted {
     my $self = shift;
     # In theory, a raw radix sort is O(N), which beats Perl's O(N log N) by
     # a fair margin. However, it _does_ discard duplicates, so ymmv.
-    my $from = [ map { [ unpack('C32', $_->{ lower }->{ address } . $_->{ upper }->{ address }) ] } @$self ];
+    my $from = [ map { [ unpack('U32', $_->{ lower }->{ address } . $_->{ upper }->{ address }) ] } @$self ];
     my $to;
     for (my $i = 31; $i >= 0; $i--) {
         $to = [];
