@@ -83,10 +83,10 @@ sub _checktype {
     my ($v) = @_;
     return $v if ref $v eq 'Net::IPAddress::Util::Range';
     if (ref $v eq 'HASH') {
-        $v = Net::IPAddress::Util::Range::IPRange($v);
+        $v = Net::IPAddress::Util::Range->new($v);
     }
     if (ref $v eq 'Net::IPAddress::Util') {
-        $v = Net::IPAddress::Util::Range::IPRange({ ip => $v });
+        $v = Net::IPAddress::Util::Range->new({ ip => $v });
     }
     if (!defined $v or ref $v ne 'Net::IPAddress::Util::Range') {
         my $disp = defined $v ? ref $v ? ref $v : 'bare scalar' : 'undef()';
